@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -40,9 +40,7 @@
 #include <glib/gi18n.h>
 
 #include "gpm-common.h"
-#include "gpm-prefs.h"
 #include "gpm-marshal.h"
-#include "egg-debug.h"
 
 #include "gpm-load.h"
 
@@ -95,18 +93,18 @@ gpm_load_get_cpu_values (long unsigned *cpu_idle, long unsigned *cpu_total)
 	   	
 	kc = kstat_open();
 	if (!kc) {
-		egg_warning ("Cannot open kstat!\n");
+		g_warning ("Cannot open kstat!\n");
 		return FALSE;
 	}
 
 	ks = kstat_lookup(kc, "unix", 0, "system_misc");
   	if (kstat_read(kc, ks, NULL) == -1) {
-		egg_warning ("Cannot read kstat on module unix!\n");
+		g_warning ("Cannot read kstat on module unix!\n");
 		goto out;
 	}
 	kn = kstat_data_lookup (ks, "ncpus");
 	if (!kn) {
-		egg_warning ("Cannot get number of cpus in current system!\n");
+		g_warning ("Cannot get number of cpus in current system!\n");
 		goto out;
 	}
 	ncpus = kn->value.ui32;
@@ -119,16 +117,16 @@ gpm_load_get_cpu_values (long unsigned *cpu_idle, long unsigned *cpu_total)
 		
 		ks = kstat_lookup(kc, "cpu_stat", count, NULL);
 		if (ks == NULL) {
-			egg_warning ("Null output for kstat on cpu%d\n", count);
+			g_warning ("Null output for kstat on cpu%d\n", count);
 			goto out;
 		}
      
 		if (kstat_read(kc, ks, &data) == -1) {
-			egg_warning ("Cannot read kstat entry on cpu%d\n", count);
+			g_warning ("Cannot read kstat entry on cpu%d\n", count);
 			goto out;
 		}
 
-		egg_debug ("cpu%d:\t%lu\t%lu\t%lu\t%lu\n", count,
+		g_debug ("cpu%d:\t%lu\t%lu\t%lu\t%lu\n", count,
 					data.cpu_sysinfo.cpu[CPU_IDLE],
 					data.cpu_sysinfo.cpu[CPU_USER],
 					data.cpu_sysinfo.cpu[CPU_KERNEL],
@@ -171,20 +169,31 @@ gpm_load_get_cpu_values (long unsigned *cpu_idle, long unsigned *cpu_total)
 	char str[80];
 	FILE *fd;
 	char *suc;
+	gboolean ret = FALSE;
 
+	/* open file */
 	fd = fopen("/proc/stat", "r");
 	if (!fd)
-		return FALSE;
+		goto out;
+
+	/* get data */
 	suc = fgets (str, 80, fd);
+	if (suc == NULL)
+		goto out;
+
+	/* parse */
 	len = sscanf (str, "%s %lu %lu %lu %lu", tmp,
 		      &cpu_user, &cpu_nice, &cpu_system, cpu_idle);
-	fclose (fd);
-	/*
-	 * Summing up all these times gives you the system uptime in jiffies.
-	 * This is what the uptime command does.
-	 */
+	if (len != 5)
+		goto out;
+
+	/* summing up all these times gives you the system uptime in jiffies */
 	*cpu_total = cpu_user + cpu_nice + cpu_system + *cpu_idle;
-	return TRUE;
+	ret = TRUE;
+out:
+	if (!fd)
+		fclose (fd);
+	return ret;
 }
 #endif /* sun & __SVR4 */
 
